# `plover.oslayer.i18n` -- System languages

This module provides utility functions related to internationalization.

```{py:module} plover.oslayer.i18n

```

```{function} get_system_language() -> str
Returns the ISO 639 code for the operating system's preferred language.
```
